@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "context.h"
@@ -42,8 +28,6 @@
 
 namespace PulseAudioQt
 {
-Context *s_context = nullptr;
-
 qint64 normalVolume()
 {
     return PA_VOLUME_NORM;
@@ -51,13 +35,21 @@ qint64 normalVolume()
 
 qint64 minimumVolume()
 {
-    return 0;
+    return PA_VOLUME_MUTED;
 }
 
 qint64 maximumVolume()
 {
-    return (PA_VOLUME_NORM / 100.0) * 150;
+    return PA_VOLUME_MAX;
 }
+
+qint64 maximumUIVolume()
+{
+    return PA_VOLUME_UI_MAX;
+}
+
+#ifndef K_DOXYGEN
+
 static bool isGoodState(int eol)
 {
     if (eol < 0) {
@@ -234,6 +226,8 @@ static void ext_stream_restore_change_source_cb(pa_context *context, const pa_ex
     }
 }
 
+#endif
+
 // --------------------------
 
 Context::Context(QObject *parent)
@@ -247,32 +241,67 @@ Context::Context(QObject *parent)
 
     d->connectToDaemon();
 
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(QStringLiteral("org.pulseaudio.Server"), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, this);
-    connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, [this] { d->connectToDaemon(); });
+    QDBusServiceWatcher *watcher =
+        new QDBusServiceWatcher(QStringLiteral("org.pulseaudio.Server"), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, this);
+    connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, [this] {
+        d->connectToDaemon();
+    });
 
-    connect(&d->m_sinks, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT sinkAdded(static_cast<Sink *>(object)); });
-    connect(&d->m_sinks, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT sinkRemoved(static_cast<Sink *>(object)); });
+    connect(&d->m_sinks, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT sinkAdded(static_cast<Sink *>(object));
+    });
+    connect(&d->m_sinks, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT sinkRemoved(static_cast<Sink *>(object));
+    });
 
-    connect(&d->m_sinkInputs, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT sinkInputAdded(static_cast<SinkInput *>(object)); });
-    connect(&d->m_sinkInputs, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT sinkInputRemoved(static_cast<SinkInput *>(object)); });
+    connect(&d->m_sinkInputs, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT sinkInputAdded(static_cast<SinkInput *>(object));
+    });
+    connect(&d->m_sinkInputs, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT sinkInputRemoved(static_cast<SinkInput *>(object));
+    });
 
-    connect(&d->m_sources, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT sourceAdded(static_cast<Source *>(object)); });
-    connect(&d->m_sources, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT sourceRemoved(static_cast<Source *>(object)); });
+    connect(&d->m_sources, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT sourceAdded(static_cast<Source *>(object));
+    });
+    connect(&d->m_sources, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT sourceRemoved(static_cast<Source *>(object));
+    });
 
-    connect(&d->m_sourceOutputs, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT sourceOutputAdded(static_cast<SourceOutput *>(object)); });
-    connect(&d->m_sourceOutputs, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT sourceOutputRemoved(static_cast<SourceOutput *>(object)); });
+    connect(&d->m_sourceOutputs, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT sourceOutputAdded(static_cast<SourceOutput *>(object));
+    });
+    connect(&d->m_sourceOutputs, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT sourceOutputRemoved(static_cast<SourceOutput *>(object));
+    });
 
-    connect(&d->m_clients, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT clientAdded(static_cast<Client *>(object)); });
-    connect(&d->m_clients, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT clientRemoved(static_cast<Client *>(object)); });
+    connect(&d->m_clients, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT clientAdded(static_cast<Client *>(object));
+    });
+    connect(&d->m_clients, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT clientRemoved(static_cast<Client *>(object));
+    });
 
-    connect(&d->m_cards, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT cardAdded(static_cast<Card *>(object)); });
-    connect(&d->m_cards, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT cardRemoved(static_cast<Card *>(object)); });
+    connect(&d->m_cards, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT cardAdded(static_cast<Card *>(object));
+    });
+    connect(&d->m_cards, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT cardRemoved(static_cast<Card *>(object));
+    });
 
-    connect(&d->m_modules, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT moduleAdded(static_cast<Module *>(object)); });
-    connect(&d->m_modules, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT moduleRemoved(static_cast<Module *>(object)); });
+    connect(&d->m_modules, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT moduleAdded(static_cast<Module *>(object));
+    });
+    connect(&d->m_modules, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT moduleRemoved(static_cast<Module *>(object));
+    });
 
-    connect(&d->m_streamRestores, &MapBaseQObject::added, this, [this](int, QObject *object) { Q_EMIT streamRestoreAdded(static_cast<StreamRestore *>(object)); });
-    connect(&d->m_streamRestores, &MapBaseQObject::removed, this, [this](int, QObject *object) { Q_EMIT streamRestoreRemoved(static_cast<StreamRestore *>(object)); });
+    connect(&d->m_streamRestores, &MapBaseQObject::added, this, [this](int, QObject *object) {
+        Q_EMIT streamRestoreAdded(static_cast<StreamRestore *>(object));
+    });
+    connect(&d->m_streamRestores, &MapBaseQObject::removed, this, [this](int, QObject *object) {
+        Q_EMIT streamRestoreRemoved(static_cast<StreamRestore *>(object));
+    });
 }
 
 ContextPrivate::ContextPrivate(Context *q)
@@ -302,23 +331,8 @@ ContextPrivate::~ContextPrivate()
 
 Context *Context::instance()
 {
-    if (!s_context) {
-        s_context = new Context;
-    }
-    return s_context;
-}
-
-void Context::ref()
-{
-    ++d->m_references;
-}
-
-void Context::unref()
-{
-    if (--d->m_references == 0) {
-        delete this;
-        s_context = nullptr;
-    }
+    static std::unique_ptr<Context> context(new Context);
+    return context.get();
 }
 
 void ContextPrivate::subscribeCallback(pa_context *context, pa_subscription_event_type_t type, uint32_t index)
@@ -423,11 +437,13 @@ void ContextPrivate::contextStateCallback(pa_context *c)
         if (m_context == c) {
             pa_context_set_subscribe_callback(c, subscribe_cb, this);
 
-            if (!PAOperation(pa_context_subscribe(c,
-                                                  (pa_subscription_mask_t)(PA_SUBSCRIPTION_MASK_SINK | PA_SUBSCRIPTION_MASK_SOURCE | PA_SUBSCRIPTION_MASK_CLIENT | PA_SUBSCRIPTION_MASK_SINK_INPUT | PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT |
-                                                                           PA_SUBSCRIPTION_MASK_CARD | PA_SUBSCRIPTION_MASK_MODULE | PA_SUBSCRIPTION_MASK_SERVER),
-                                                  nullptr,
-                                                  nullptr))) {
+            if (!PAOperation(
+                    pa_context_subscribe(c,
+                                         (pa_subscription_mask_t)(PA_SUBSCRIPTION_MASK_SINK | PA_SUBSCRIPTION_MASK_SOURCE | PA_SUBSCRIPTION_MASK_CLIENT
+                                                                  | PA_SUBSCRIPTION_MASK_SINK_INPUT | PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT
+                                                                  | PA_SUBSCRIPTION_MASK_CARD | PA_SUBSCRIPTION_MASK_MODULE | PA_SUBSCRIPTION_MASK_SERVER),
+                                         nullptr,
+                                         nullptr))) {
                 qCWarning(PULSEAUDIOQT) << "pa_context_subscribe() failed";
                 return;
             }
@@ -486,7 +502,9 @@ void ContextPrivate::contextStateCallback(pa_context *c)
             m_context = nullptr;
         }
         reset();
-        QTimer::singleShot(1000, q, [this] { connectToDaemon(); });
+        QTimer::singleShot(1000, q, [this] {
+            connectToDaemon();
+        });
     }
 }
 
@@ -703,7 +721,12 @@ Server *Context::server() const
     return d->m_server;
 }
 
-void ContextPrivate::setGenericVolume(quint32 index, int channel, qint64 newVolume, pa_cvolume cVolume, const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &pa_set_volume)
+void ContextPrivate::setGenericVolume(
+    quint32 index,
+    int channel,
+    qint64 newVolume,
+    pa_cvolume cVolume,
+    const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &pa_set_volume)
 {
     if (!m_context) {
         return;
@@ -725,7 +748,9 @@ void ContextPrivate::setGenericVolume(quint32 index, int channel, qint64 newVolu
     }
 }
 
-void ContextPrivate::setGenericMute(quint32 index, bool mute, const std::function<pa_operation *(pa_context *, uint32_t, int, pa_context_success_cb_t, void *)> &pa_set_mute)
+void ContextPrivate::setGenericMute(quint32 index,
+                                    bool mute,
+                                    const std::function<pa_operation *(pa_context *, uint32_t, int, pa_context_success_cb_t, void *)> &pa_set_mute)
 {
     if (!m_context) {
         return;
@@ -736,7 +761,9 @@ void ContextPrivate::setGenericMute(quint32 index, bool mute, const std::functio
     }
 }
 
-void ContextPrivate::setGenericPort(quint32 index, const QString &portName, const std::function<pa_operation *(pa_context *, uint32_t, const char *, pa_context_success_cb_t, void *)> &pa_set_port)
+void ContextPrivate::setGenericPort(quint32 index,
+                                    const QString &portName,
+                                    const std::function<pa_operation *(pa_context *, uint32_t, const char *, pa_context_success_cb_t, void *)> &pa_set_port)
 {
     if (!m_context) {
         return;
@@ -747,7 +774,10 @@ void ContextPrivate::setGenericPort(quint32 index, const QString &portName, cons
     }
 }
 
-void ContextPrivate::setGenericDeviceForStream(quint32 streamIndex, quint32 deviceIndex, const std::function<pa_operation *(pa_context *, uint32_t, uint32_t, pa_context_success_cb_t, void *)> &pa_move_stream_to_device)
+void ContextPrivate::setGenericDeviceForStream(
+    quint32 streamIndex,
+    quint32 deviceIndex,
+    const std::function<pa_operation *(pa_context *, uint32_t, uint32_t, pa_context_success_cb_t, void *)> &pa_move_stream_to_device)
 {
     if (!m_context) {
         return;
