@@ -1,21 +1,7 @@
 /*
-    Copyright 2018 Nicolas Fella <nicolas.fella@gmx.de>
+    SPDX-FileCopyrightText: 2018 Nicolas Fella <nicolas.fella@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #ifndef CONTEXT_P_H
 #define CONTEXT_P_H
@@ -31,7 +17,6 @@
 
 namespace PulseAudioQt
 {
-
 class Server;
 
 class ContextPrivate
@@ -71,10 +56,18 @@ public:
     void streamRestoreCallback(const pa_ext_stream_restore_info *info);
     void serverCallback(const pa_server_info *info);
     void streamRestoreWrite(const pa_ext_stream_restore_info *info);
-    void setGenericVolume(quint32 index, int channel, qint64 newVolume, pa_cvolume cVolume, const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &);
+    void setGenericVolume(quint32 index,
+                          int channel,
+                          qint64 newVolume,
+                          pa_cvolume cVolume,
+                          const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &);
     void setGenericMute(quint32 index, bool mute, const std::function<pa_operation *(pa_context *, uint32_t, int, pa_context_success_cb_t, void *)> &);
-    void setGenericPort(quint32 index, const QString &portName, const std::function<pa_operation *(pa_context *, uint32_t, const char *, pa_context_success_cb_t, void *)> &);
-    void setGenericDeviceForStream(quint32 streamIndex, quint32 deviceIndex, const std::function<pa_operation *(pa_context *, uint32_t, uint32_t, pa_context_success_cb_t, void *)> &);
+    void setGenericPort(quint32 index,
+                        const QString &portName,
+                        const std::function<pa_operation *(pa_context *, uint32_t, const char *, pa_context_success_cb_t, void *)> &);
+    void setGenericDeviceForStream(quint32 streamIndex,
+                                   quint32 deviceIndex,
+                                   const std::function<pa_operation *(pa_context *, uint32_t, uint32_t, pa_context_success_cb_t, void *)> &);
     void reset();
     void connectToDaemon();
 
