@@ -1,22 +1,8 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "models.h"
@@ -43,14 +29,16 @@ AbstractModel::AbstractModel(const MapBaseQObject *map, QObject *parent)
     : QAbstractListModel(parent)
     , d(new AbstractModelPrivate(this, map))
 {
-    Context::instance()->ref();
-
-    connect(d->m_map, &MapBaseQObject::aboutToBeAdded, this, [this](int index) { beginInsertRows(QModelIndex(), index, index); });
+    connect(d->m_map, &MapBaseQObject::aboutToBeAdded, this, [this](int index) {
+        beginInsertRows(QModelIndex(), index, index);
+    });
     connect(d->m_map, &MapBaseQObject::added, this, [this](int index) {
         onDataAdded(index);
         endInsertRows();
     });
-    connect(d->m_map, &MapBaseQObject::aboutToBeRemoved, this, [this](int index) { beginRemoveRows(QModelIndex(), index, index); });
+    connect(d->m_map, &MapBaseQObject::aboutToBeRemoved, this, [this](int index) {
+        beginRemoveRows(QModelIndex(), index, index);
+    });
     connect(d->m_map, &MapBaseQObject::removed, this, [this](int index) {
         Q_UNUSED(index);
         endRemoveRows();
@@ -59,9 +47,6 @@ AbstractModel::AbstractModel(const MapBaseQObject *map, QObject *parent)
 
 AbstractModel::~AbstractModel()
 {
-    // deref context after we've deleted this object
-    // see https://bugs.kde.org/show_bug.cgi?id=371215
-    Context::instance()->unref();
     delete d;
 }
 
@@ -103,7 +88,7 @@ QVariant AbstractModel::data(const QModelIndex &index, int role) const
     if (role == PulseObjectRole) {
         return QVariant::fromValue(data);
     } else if (role == Qt::DisplayRole) {
-        return static_cast<PulseObject *>(data)->properties().value(QStringLiteral("name")).toString();
+        return static_cast<PulseObject *>(data)->name();
     }
     int property = d->m_objectProperties.value(role, -1);
     if (property == -1) {
