@@ -1,22 +1,8 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PULSEAUDIO_H
@@ -24,7 +10,7 @@
 
 #include <QAbstractListModel>
 
-#include "kf5pulseaudioqt_export.h"
+#include "pulseaudioqt_export.h"
 
 namespace PulseAudioQt
 {
@@ -35,7 +21,7 @@ class Source;
 class AbstractModelPrivate;
 class SinkModelPrivate;
 
-class KF5PULSEAUDIOQT_EXPORT AbstractModel : public QAbstractListModel
+class PULSEAUDIOQT_EXPORT AbstractModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
@@ -47,7 +33,7 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     bool setData(const QModelIndex &index, const QVariant &value, int role) final override;
 
-    int role(const QByteArray &roleName) const;
+    Q_INVOKABLE int role(const QByteArray &roleName) const;
 
 protected:
     AbstractModel(const MapBaseQObject *map, QObject *parent);
@@ -71,7 +57,7 @@ private:
     }
 };
 
-class KF5PULSEAUDIOQT_EXPORT CardModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT CardModel : public AbstractModel
 {
     Q_OBJECT
 public:
@@ -81,7 +67,7 @@ private:
     void *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT SinkModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT SinkModel : public AbstractModel
 {
     Q_OBJECT
     Q_PROPERTY(PulseAudioQt::Sink *defaultSink READ defaultSink NOTIFY defaultSinkChanged)
@@ -108,7 +94,7 @@ private:
     SinkModelPrivate *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT SinkInputModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT SinkInputModel : public AbstractModel
 {
     Q_OBJECT
 public:
@@ -118,7 +104,7 @@ private:
     void *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT SourceModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT SourceModel : public AbstractModel
 {
     Q_OBJECT
     Q_PROPERTY(PulseAudioQt::Source *defaultSource READ defaultSource NOTIFY defaultSourceChanged)
@@ -137,7 +123,7 @@ private:
     void *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT SourceOutputModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT SourceOutputModel : public AbstractModel
 {
     Q_OBJECT
 public:
@@ -147,7 +133,7 @@ private:
     void *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT StreamRestoreModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT StreamRestoreModel : public AbstractModel
 {
     Q_OBJECT
 public:
@@ -157,7 +143,7 @@ private:
     void *d;
 };
 
-class KF5PULSEAUDIOQT_EXPORT ModuleModel : public AbstractModel
+class PULSEAUDIOQT_EXPORT ModuleModel : public AbstractModel
 {
     Q_OBJECT
 public:
