@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "pulseobject.h"
@@ -40,7 +26,6 @@ PulseObject::~PulseObject()
 
 PulseObjectPrivate::PulseObjectPrivate(PulseObject *q)
     : q(q)
-    , m_index(0)
 {
 }
 
@@ -48,14 +33,9 @@ PulseObjectPrivate::~PulseObjectPrivate()
 {
 }
 
-Context *PulseObject::context() const
+QString PulseObject::name() const
 {
-    return Context::instance();
-}
-
-uint32_t PulseObject::index() const
-{
-    return d->m_index;
+    return d->m_name;
 }
 
 QString PulseObject::iconName() const
