@@ -1,21 +1,7 @@
 /*
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "streamrestore.h"
@@ -35,8 +21,7 @@ StreamRestore::StreamRestore(quint32 index, const QVariantMap &properties, QObje
     memset(&d->m_volume, 0, sizeof(d->m_volume));
     memset(&d->m_channelMap, 0, sizeof(d->m_channelMap));
 
-    d->m_muted = false;
-    PulseObject::d->m_index = index;
+    d->m_index = index;
     PulseObject::d->m_properties = properties;
 }
 
@@ -55,12 +40,9 @@ StreamRestorePrivate::~StreamRestorePrivate()
 
 void StreamRestorePrivate::update(const pa_ext_stream_restore_info *info)
 {
+    q->PulseObject::d->updatePulseObject(info);
     m_cache.valid = false;
-    const QString infoName = QString::fromUtf8(info->name);
-    if (m_name != infoName) {
-        m_name = infoName;
-        Q_EMIT q->nameChanged();
-    }
+
     const QString infoDevice = QString::fromUtf8(info->device);
     if (m_device != infoDevice) {
         m_device = infoDevice;
@@ -86,11 +68,6 @@ void StreamRestorePrivate::update(const pa_ext_stream_restore_info *info)
     }
 }
 
-QString StreamRestore::name() const
-{
-    return d->m_name;
-}
-
 QString StreamRestore::device() const
 {
     return d->m_device;
@@ -197,7 +174,7 @@ void StreamRestore::setDeviceIndex(quint32 deviceIndex)
 
 void StreamRestorePrivate::writeChanges(const pa_cvolume &volume, bool muted, const QString &device)
 {
-    const QByteArray nameData = m_name.toUtf8();
+    const QByteArray nameData = q->name().toUtf8();
     const QByteArray deviceData = device.toUtf8();
 
     pa_ext_stream_restore_info info;
@@ -212,7 +189,12 @@ void StreamRestorePrivate::writeChanges(const pa_cvolume &volume, bool muted, co
     m_cache.muted = muted;
     m_cache.device = device;
 
-    q->context()->d->streamRestoreWrite(&info);
+    Context::instance()->d->streamRestoreWrite(&info);
+}
+
+quint32 StreamRestore::index() const
+{
+    return d->m_index;
 }
 
 } // PulseAudioQt
