@@ -1,28 +1,14 @@
 /*
-    Copyright 2018 Nicolas Fella <nicolas.fella@gmx.de>
+    SPDX-FileCopyrightText: 2018 Nicolas Fella <nicolas.fella@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #ifndef VOLUMEOBJECT_P_H
 #define VOLUMEOBJECT_P_H
 
 #include <pulse/volume.h>
 
-#include "pulseobject_p.h"
+#include "indexedpulseobject_p.h"
 #include "volumeobject.h"
 
 namespace PulseAudioQt
@@ -35,17 +21,18 @@ public:
     VolumeObject *q;
     pa_channel_map foo;
     pa_cvolume m_volume;
-    bool m_muted;
-    bool m_hasVolume;
-    bool m_volumeWritable;
+    bool m_muted = true;
+    bool m_volumeWritable = true;
     QVector<QString> m_channels;
     QStringList m_rawChannels;
 
     pa_cvolume cvolume() const;
 
-    template<typename PAInfo> void updateVolumeObject(PAInfo *info)
+    template<typename PAInfo>
+    void updateVolumeObject(PAInfo *info)
     {
-        q->PulseObject::d->updatePulseObject(info);
+        q->IndexedPulseObject::d->updatePulseObject(info);
+        q->PulseObject::d->updateProperties(info);
         if (m_muted != info->mute) {
             m_muted = info->mute;
             Q_EMIT q->mutedChanged();
